@@ -1,4 +1,4 @@
-# This code is part of Perl distribution Mail-Message version 3.019.
+# This code is part of Perl distribution Mail-Message version 3.020.
 # The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
@@ -10,7 +10,7 @@
 
 
 package Mail::Message::Field::Date;{
-our $VERSION = '3.019';
+our $VERSION = '3.020';
 }
 
 use base 'Mail::Message::Field::Structured';
@@ -33,30 +33,30 @@ sub parse($)
 {	my ($self, $string) = @_;
 
 	my ($dn, $d, $mon, $y, $h, $min, $s, $z) = $string =~ m/
-		 ^ \s*
-			(?: ($dayname) \s* \, \s* )?
-			( 0?[1-9] | [12][0-9] | 3[01] ) \s*    # day
-			\s+ ( [A-Z][a-z][a-z]|[0-9][0-9] ) \s+ # month(
-				(?: 19 | 20 | ) [0-9][0-9] ) \s+     # year(
-					[0-1]?[0-9] | 2[0-3] ) \s*    # hour
-				[:.] ( [0-5][0-9] ) \s*            # minute
-			(?: [:.] ( [0-5][0-9] ) )? \s+         # second(
-				[+-][0-9]{4} | [A-Z]+ )?             # zone
+		 ^	\s*
+			(?: ($dayname) \s* \, \s* )?         # dayname (optional)
+			( 0?[1-9] | [12][0-9] | 3[01] ) \s+  # day
+			( [A-Z][a-z][a-z]|[0-9][0-9]  ) \s+  # month
+			( (?: 19 | 20 | ) [0-9][0-9]  ) \s+  # year
+			( [0-1]?[0-9] | 2[0-3] )        \s*  # hour
+				[:.] ( [0-5][0-9] )         \s*  # minute
+			(?: [:.] ( [0-5][0-9] ) )?      \s*  # second (optional)
+			( [+-][0-9]{4} | [A-Z]+ )?           # zone
 			\s*
-	 /x or return undef;
+		$ /x or return undef;
 
-	defined $dn or $dn = '';
-	$dn  =~ s/\s+//g;
-	$mon = $months[$mon-1] if $mon =~ /[0-9]+/;   # Broken mail clients
+	$dn //= '';
+	$dn   =~ s/\s+//g;
+	$mon  = $months[$mon-1] if $mon =~ /[0-9]+/;   # Broken mail clients
 
-	$y  += 2000 if $y < 50;
-	$y  += 1900 if $y < 100;
+	$y   += 2000 if $y < 50;
+	$y   += 1900 if $y < 100;
 
-	$z ||= '-0000';
-	$z   =  $tz{$z} || '-0000' if $z =~ m/[A-Z]/;
+	$z  ||= '-0000';
+	$z    = $tz{$z} || '-0000' if $z =~ m/[A-Z]/;
 
-	$self->{MMFD_date} = sprintf "%s%s%02d %s %04d %02d:%02d:%02d %s",
-		$dn, (length $dn ? ', ' : ''), $d, $mon, $y, $h, $min, $s, $z;
+	$self->{MMFD_date} = sprintf "%s%02d %s %04d %02d:%02d:%02d %s",
+		(length $dn ? "$dn, " : ''), $d, $mon, $y, $h, $min, $s // 0, $z;
 
 	$self;
 }
